@@ -23,7 +23,7 @@ our %EXPORT_TAGS = ( 'all' => [ qw( ) ] );
 our @EXPORT_OK = ( @{ $EXPORT_TAGS{'all'} } );
 
 our @EXPORT = qw( new register authorised callback errstr valid_callback_host );
-our $VERSION = '1.01';
+our $VERSION = '1.02';
 
 my %args = ();
 
@@ -256,7 +256,6 @@ sub callback
     my %required = ( instId => 1,
                      cartId => 1,
                      desc => 1,
-                     transId => 1,
                      transStatus => 1,
                    );
     
@@ -290,6 +289,7 @@ sub callback
         $required{authCurrency} = 1;
         $required{authAmount} = 1;
         $required{transTime} = 1;
+        $required{transId} = l;
         }
     
     foreach my $field (@fields)
